@@ -512,7 +512,7 @@ def load_model(model_file):
         model.is_trained = True
 
     # Then try loading it with pickle:
-    except KeyError:
+    except (KeyError, UnicodeDecodeError):
         logging.info("Loading mokapot model.")
         with open(model_file, "rb") as mod_in:
             model = pickle.load(mod_in)
